@@ -175,20 +175,12 @@ class TableFormat(str, enum.Enum):
     TABS = "tabs"
 
 
-def iter_character_tab(table: tablib.Dataset) -> Iterable[str]:
-    characters, lines = table[Column.CHAR], table[Column.CLINE]
-    yield f'=== "{Column.CHAR.value}"'
-    for character, line_count in zip(characters, lines):
-        yield f"    - {character} ({line_count} lines)"
-    yield ""
-
-
 def iter_scene_tab(table: tablib.Dataset, scene_name: str) -> Iterable[str]:
     characters, scene = table[Column.CHAR], table[scene_name]
     yield f'=== "{scene_name}"'
     for character, marker in zip(characters, scene):
         if marker:
-            yield f"    - {character} ⇒ {marker}"
+            yield f"    - [{character} ⇒ {marker.lstrip('[')}"
     yield ""
 
 
@@ -198,11 +190,13 @@ def iter_grid_tab(table: tablib.Dataset) -> Iterable[str]:
     yield ""
 
 
-def iter_tabs(table: tablib.Dataset, *, __headers=frozenset(Column)):
-    yield from iter_character_tab(table)
+def iter_tabs(
+    table: tablib.Dataset, *, include_grid: bool = True, __headers=frozenset(Column)
+):
     for header in (h for h in table.headers if h not in __headers):
         yield from iter_scene_tab(table, header)
-    yield from iter_grid_tab(table)
+    if include_grid:
+        yield from iter_grid_tab(table)
 
 
 def export_tabs(table: tablib.Dataset) -> str:
